import WebpackDevServer from 'webpack-dev-server';
import pushStateServer from 'pushstate-server';

import logger from '../logger';
import getCompiler from '../helper/getCompiler';
import build from './build';

import {
  resolvePath,
} from '../utils';

import {
  PORT,
} from '../config';

const IS_PRODUCTION = process.env.NODE_ENV === 'production';

export default function start() {
  const PUBLIC_PATH = resolvePath('public');

  if (IS_PRODUCTION) {
    build()
      .then(() => {
        pushStateServer.start({
          port: PORT,
          directory: PUBLIC_PATH,
        });
      })
      .catch((errors) => {
        errors.forEach(error => logger.error(error));
      });

    return;
  }

  const devServer = new WebpackDevServer(getCompiler(), {
    hot: true,
    noInfo: true,
    inline: true,
    historyApiFallback: {
      rewrites: [
        {
          from: /\./,
          to: '/',
        },
      ],
    },
    contentBase: PUBLIC_PATH,
  });

  devServer.listen(PORT);

  logger.info(`Server started at ${PORT} in 'Development'`);
}
